@@ -8,12 +8,12 @@ from typing import Union, List, Any
 from PIL import Image
 from selenium.common.exceptions import NoSuchElementException, TimeoutException, StaleElementReferenceException
 from appium.webdriver.webdriver import WebDriver as AppiumWebDriver
-from selenium.webdriver import ActionChains
 from selenium.webdriver.remote.webdriver import WebDriver as SeleniumWebDriver
 from selenium.webdriver.remote.webelement import WebElement as SeleniumWebElement
 from selenium.webdriver.support import expected_conditions as ec
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.common.exceptions import WebDriverException
+from selenium.webdriver import ActionChains
 
 from dyatel.shared_utils import cut_log_data
 from dyatel.internal_utils import get_child_elements, Mixin, WAIT_EL
@@ -33,8 +33,6 @@ class CoreElement(Mixin):
         :param name: name of element (will be attached to logs)
         :param parent: parent of element. Can be Web/MobileElement, Web/MobilePage or Group objects
         """
-        self.driver = CoreDriver.driver
-        self.driver_wrapper = CoreDriver(self.driver)
         self.parent: Union[CoreElement, Any] = parent if parent else None
         self.wait = wait
 
@@ -46,10 +44,11 @@ class CoreElement(Mixin):
         self.name = name if name else self.locator
 
         self._element = None
+        self._initialized = True
 
         self.child_elements: List[CoreElement] = get_child_elements(self, CoreElement)
         for el in self.child_elements:  # required for Group  # TODO: maybe need to replace with function call
-            if not el.driver:
+            if not getattr(el, '_initialized'):
                 el.__init__(
                     locator=el.locator,
                     locator_type=el.locator_type,
@@ -299,7 +298,8 @@ class CoreElement(Mixin):
 
         :return: True if present in DOM
         """
-        return bool(len(getattr(self, 'all_elements')))
+        is_available = self._get_driver(wait=False).find_elements(self.locator_type, self.locator)
+        return bool(len(is_available))
 
     def is_displayed(self, silent=False) -> bool:
         """
@@ -369,6 +369,24 @@ class CoreElement(Mixin):
         self.wait_element(silent=True)
         return len(getattr(self, 'all_elements'))
 
+    @property
+    def driver(self) -> Union[AppiumWebDriver, SeleniumWebDriver]:
+        """
+        Get source driver instance
+
+        :return: SeleniumWebDriver for web test or AppiumWebDriver for mobile tests
+        """
+        return CoreDriver.driver
+
+    @property
+    def driver_wrapper(self) -> CoreDriver:
+        """
+        Get source driver wrapper instance
+
+        :return: CoreDriver
+        """
+        return CoreDriver.driver_wrapper
+
     # Mixin
 
     def _get_driver(self, wait=True) -> Union[SeleniumWebDriver, SeleniumWebElement]:
@@ -381,7 +399,11 @@ class CoreElement(Mixin):
         if self.parent:
             debug(f'Get element "{self.name}" from parent element "{self.parent.name}"')
             if wait:
-                self.parent.wait_element(silent=True)
+                if isinstance(self, CoreElement):
+                    self.wait_element(silent=True)
+                else:
+                    wait_page_loaded = getattr(self, 'wait_page_loaded')
+                    wait_page_loaded(silent=True)
 
             base = self.parent._element
 
@@ -396,7 +418,7 @@ class CoreElement(Mixin):
 
         :return: driver
         """
-        return WebDriverWait(self._get_driver(), timeout)
+        return WebDriverWait(self.driver, timeout)
 
     @property
     def _action_chains(self) -> ActionChains:
@@ -405,7 +427,7 @@ class CoreElement(Mixin):
 
         :return: ActionChains
         """
-        return ActionChains(self._get_driver())
+        return ActionChains(self.driver)
 
     def _scaled_screenshot(self, screenshot_binary, width) -> Image:
         """
